TBLPropertiesUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
setUnitExtraProps(
HashMap< String, String> extraProperties, HashMap<String, TBLExtraPropertyWithLevel> unitExtraProperties, String unitType, String uniqueUnitId) → Set<String> - Set the extra properties for a unit Stores locally with unit-level tag (always overwrites page/global) Returns a set of property keys that were updated
-
shouldUpdateGlobalExtraProperty(
String incomingPropertyKey, TBLExtraPropertyWithLevel incomingExtraProperty, Map< String, TBLExtraPropertyWithLevel> _globalExtraProperties) → bool - Determines if a global extra property should be updated.
-
shouldUpdateLocalExtraProperty(
String incomingPropertyKey, TBLExtraPropertyWithLevel incomingExtraProperty, Map< String, TBLExtraPropertyWithLevel> targetExtraProperties) → bool - Determines if a local extra property should be updated.
-
stringifyExtraProperties(
HashMap< String, TBLExtraPropertyWithLevel> pageExtraProperties) → HashMap<String, String> - Converts extra properties with levels to JSON-encoded strings. Properties that fail to encode are skipped and logged.
-
stringToBool(
String? value) → bool? - Converts a string to a boolean value.
-
updateExtraProperties(
HashMap< String, String> incomingProperties, Map<String, TBLExtraPropertyWithLevel> targetExtraProperties, TBLExtraPropertyLevel incomingPropertiesLevel) → bool - Updates extra properties at the specified level, filtering empty keys/values.
Constants
- KEEP_ALIVE_KEY → const String
-
RECOGNIZED_EXTRA_PROPERTIES
→ const List<
String> - USER_OPT_OUT_KEY → const String